{"currentPage":1,"currentResult":0,"entityOrField":false,"items":[{"bfzcj":91,"bh_id":"F19000001","bj":"F1900001","cj":"91","cjsfzf":"否","date":"二○二○年一月三十日","dateDigit":"2020年1月30日","dateDigitSeparator":"2020-1-30","day":"30","jd":"4.00","jg_id":"03000","jgmc":"电子信息与电气工程学院","jgpxzd":"1","jsxm":"麦亦勇","jxb_id":"90DD3334A9410650E0530200A8C03235","jxbmc":"(2019-2020-1)-CA001-10","kcbj":"主修","kch":"CA001","kch_id":"CA001","kclbmc":"个性化教育课程","kcmc":"大学化学","kcxzdm":"01","kcxzmc":"必修","key":"","khfsmc":"考试","kkbmmc":"化学化工学院","ksxz":"正常考试","ksxzdm":"01","listnav":"false","localeKey":"zh_CN","month":"1","njdm_id":"2019","njmc":"2019","pageable":true,"queryModel":{"currentPage":1,"currentResult":0,"entityOrField":false,"limit":15,"offset":0,"pageNo":0,"pageSize":15,"showCount":10,"sorts":[],"totalCount":0,"totalPage":0,"totalResult":0},"rangeable":true,"row_id":"1","sfxwkc":"否","totalResult":"3","userModel":{"monitor":false,"roleCount":0,"roleKeys":"","roleValues":"","status":0,"usable":false},"xb":"女","xbm":"0","xf":"2","xh":"519027910001","xh_id":"","xm":"林芳","xnm":"2019","xnmmc":"2019-2020","xqm":"3","xqmmc":"1","xsbjmc":"工科平台学生","xslb":"本科生(中国国籍)","year":"2020","zyh_id":"080605","zymc":"计算机科学与技术"},{"bfzcj":91,"bh_id":"F1900001","bj":"F1900001","cj":"91","cjsfzf":"否","date":"二○二○年一月三十日","dateDigit":"2020年1月30日","dateDigitSeparator":"2020-1-30","day":"30","jd":"4.00","jg_id":"03000","jgmc":"电子信息与电气工程学院","jgpxzd":"1","jsxm":"韩莉","jxb_id":"90D41E26C9AE7D5BE0530200A8C0F7D4","jxbmc":"(2019-2020-1)-CA044-4","kcbj":"主修","kch":"CA044","kch_id":"CA044","kclbmc":"实验课程","kcmc":"大学化学实验","kcxzdm":"01","kcxzmc":"必修","key":"","khfsmc":"考核","kkbmmc":"化学化工学院","ksxz":"正常考试","ksxzdm":"01","listnav":"false","localeKey":"zh_CN","month":"1","njdm_id":"2019","njmc":"2019","pageable":true,"queryModel":{"currentPage":1,"currentResult":0,"entityOrField":false,"limit":15,"offset":0,"pageNo":0,"pageSize":15,"showCount":10,"sorts":[],"totalCount":0,"totalPage":0,"totalResult":0},"rangeable":true,"row_id":"2","sfxwkc":"否","totalResult":"3","userModel":{"monitor":false,"roleCount":0,"roleKeys":"","roleValues":"","status":0,"usable":false},"xb":"女","xbm":"0","xf":"1","xh":"519027910001","xh_id":"","xm":"林芳","xnm":"2019","xnmmc":"2019-2020","xqm":"3","xqmmc":"1","xsbjmc":"工科平台学生","xslb":"本科生(中国国籍)","year":"2020","zyh_id":"080605","zymc":"计算机科学与技术"},{"bfzcj":97,"bh_id":"F1900001","bj":"F1900001","cj":"97","cjsfzf":"否","date":"二○二○年一月三十日","dateDigit":"2020年1月30日","dateDigitSeparator":"2020-1-30","day":"30","jd":"4.30","jg_id":"03000","jgmc":"电子信息与电气工程学院","jgpxzd":"1","jsxm":"朱弘恣","jxb_id":"90BEF7AA59D97072E0530200A8C06959","jxbmc":"(2019-2020-1)-CS154-9","kcbj":"主修","kch":"CS154","kch_id":"CS154","kclbmc":"个性化教育课程","kcmc":"程序设计思想与方法（C++）","kcxzdm":"01","kcxzmc":"必修","key":"","khfsmc":"考试","kkbmmc":"电子信息与电气工程学院","ksxz":"正常考试","ksxzdm":"01","listnav":"false","localeKey":"zh_CN","month":"1","njdm_id":"2019","njmc":"2019","pageable":true,"queryModel":{"currentPage":1,"currentResult":0,"entityOrField":false,"limit":15,"offset":0,"pageNo":0,"pageSize":15,"showCount":10,"sorts":[],"totalCount":0,"totalPage":0,"totalResult":0},"rangeable":true,"row_id":"3","sfxwkc":"否","totalResult":"3","userModel":{"monitor":false,"roleCount":0,"roleKeys":"","roleValues":"","status":0,"usable":false},"xb":"女","xbm":"0","xf":"3.0","xh":"519027910001","xh_id":"","xm":"林芳","xnm":"2019","xnmmc":"2019-2020","xqm":"3","xqmmc":"1","xsbjmc":"工科平台学生","xslb":"本科生(中国国籍)","year":"2020","zyh_id":"080605","zymc":"计算机科学与技术"}],"limit":15,"offset":0,"pageNo":0,"pageSize":15,"showCount":15,"sortName":"xnmmc asc,xqmmc asc","sortOrder":" ","sorts":[],"totalCount":3,"totalPage":1,"totalResult":3}